node_program_editor library
Classes
- EditorCanvas
- EditorController
- NodeData
-
The
NodeDataclass in Dart represents data for a node with properties like colors, ports, node type, name, icon, and icon color, and provides methods for JSON serialization and deserialization. - Port
-
The
Portclass represents a port with an ID, maximum number of links, label, and position in Dart, with methods for copying and converting to/from JSON.